summaryrefslogtreecommitdiffstats
path: root/content/public/common/content_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/public/common/content_client.h')
-rw-r--r--content/public/common/content_client.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/content/public/common/content_client.h b/content/public/common/content_client.h
index 5bd865d..eabd3da 100644
--- a/content/public/common/content_client.h
+++ b/content/public/common/content_client.h
@@ -88,10 +88,11 @@ class CONTENT_EXPORT ContentClient {
virtual void AddPepperPlugins(
std::vector<content::PepperPluginInfo>* plugins) {}
// Gives the embedder a chance to register its own standard and saveable
// url schemes early on in the startup sequence.
virtual void AddAdditionalSchemes(
std::vector<url::SchemeWithType>* standard_schemes,
+ std::vector<url::SchemeWithType>* referrer_schemes,
std::vector<std::string>* savable_schemes) {}
// Returns whether the given message should be sent in a swapped out renderer.
@@ -88,10 +88,11 @@ class CONTENT_EXPORT ContentClient {
virtual void AddPepperPlugins(
std::vector<content::PepperPluginInfo>* plugins) {}
- // Gives the embedder a chance to register its own standard and saveable
- // url schemes early on in the startup sequence.
+ // Gives the embedder a chance to register its own standard, referrer and
+ // saveable url schemes early on in the startup sequence.
virtual void AddAdditionalSchemes(
std::vector<url::SchemeWithType>* standard_schemes,